@@ -98,6 +98,9 @@ our %DATA_MAP= (
    writeDiff => 0,
    cache => 0,
    fields => {
+       MMANUFACTURER => {},
+       MMODEL => {},
+       MSN => {},
        SMANUFACTURER => {},
        SMODEL => {},
        SSN => {},
@@ -364,31 +367,6 @@ our %DATA_MAP= (
    }
   },
 
-  softwares => {
-    mask => 65536,
-    multi => 1,
-    auto => 1,
-    delOnReplace => 1,
-    sortBy => 'NAME',
-    writeDiff => 1,
-    cache => 1,
-    fields =>  {
-       PUBLISHER => {},
-       NAME => { cache => 1 },
-       VERSION => {},
-       FOLDER => {},
-       COMMENTS => {},
-       FILENAME => {},
-       FILESIZE => { fallback=>0 },
-       SOURCE => { fallback=>0 },
-       GUID => {},
-       LANGUAGE => {},
-       INSTALLDATE => {},
-       BITSWIDTH => {},
-       CATEGORY => {}
-    }
-  },
-
   virtualmachines => {
     mask => 131072,
     multi => 1,
@@ -446,7 +424,8 @@ our %DATA_MAP= (
       OPNAME => {},
       COUNTRY => {},
       SERIALNUMBER => {},
-      DEVICEID => {}
+      DEVICEID => {},
+      PHONENUMBER => {}
     }
   },
 
