@@ -92,14 +92,6 @@ function printEnTete_tab($ent) {
 	<tr height=40px bgcolor=#f2f2f2 align=center><td><b>" . $ent . "</b></td></tr></table>";
 }
 
-function xml_escape_string($array) {
-    foreach ($array as $key => $value) {
-        $trait_array[$key] = utf8_encode($value);
-        $trait_array[$key] = htmlspecialchars($value, ENT_QUOTES);
-    }
-    return $trait_array;
-}
-
 function xml_encode($txt) {
     $cherche = array("&", "<", ">", "\"", "'", "é", "è", "ô", "Î", "î", "à", "ç", "ê", "â");
     $replace = array("&amp;", "&lt;", "&gt;", "&quot;", "&apos;", "&eacute;", "&egrave;", "&ocirc;", "&Icirc;", "&icirc;", "&agrave;", "&ccedil;", "&ecirc;", "&acirc;");
@@ -160,6 +152,10 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
         "STAT",
         "ACTIVE",
         "MAC",
+		"EDIT_DEPLOY",
+		"SHOW_DETAILS",
+		"ARCHIVER",
+		"RESTORE",
     );
     //If the column selected are different from the default columns
     if (!empty($_COOKIE[$option['table_name'] . "_col"])) {
@@ -183,10 +179,14 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
     }
     $actions = array(
         "MODIF",
+		"EDIT_DEPLOY",
         "SUP",
         "ZIP",
         "STAT",
-        "ACTIVE",
+		"ACTIVE",
+		"SHOW_DETAILS",
+		"ARCHIVER",
+		"RESTORE",
     );
     $action_visible = false;
 
@@ -217,11 +217,11 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
         </div>
         <?php
 
-				if (!isset ($protectedPost['COL_SEARCH'])){
-						 $selected_col='ALL';
-				} else {
-						 $selected_col = $protectedPost['COL_SEARCH'];
-				}
+		if (!isset ($protectedPost['COL_SEARCH'])){
+			$selected_col='ALL';
+		} else {
+			$selected_col = $protectedPost['COL_SEARCH'];
+		}
 
         //Display the Column selector
         if (!empty($list_col_can_del)) {
@@ -259,34 +259,6 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
                 </div>
             </div>
 
-						<!-- Display search in column bar-->
-						<div class="row">
-							 <div class="col col-md-4 col-xs-offset-0 col-md-offset-4">
-									<div class="form-group">
-										<label class="control-label col-sm-4" for="select_col<?php echo $option['table_name']; ?>"> <?php echo $l->g(1419); ?> : </label>
-											<div class="col-sm-8">
-												<select class="form-control" id="select_search_col<?php echo $option['table_name']; ?>" name="COL_SEARCH">
-														<option value="default"><?php echo $l->g(6012); ?></option>
-																<?php
-																	foreach ($list_col_can_del as $key => $col) {
-																			$name = explode('.', $col);
-																			$name = explode(' as ', end($name));
-																			$value = end($name);
-																			if (!empty($option['REPLACE_COLUMN_KEY'][$key])) {
-																					$value = $option['REPLACE_COLUMN_KEY'][$key];
-																			}
-																			if (array_key_exists($key, $lbl_column)) {
-																					echo "<option value='$value'>$lbl_column[$key]</option>";
-																			} else {
-																				  echo "<option value='$value'>$key</option>";
-																			}
-																	}
-															 ?>
-												</select>
-											</div>
-										</div>
-									</div>
-								</div>
             <?php
         }
         ?>
@@ -308,7 +280,7 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
     </div>
 
     <script>
-        //Check all the checkbox
+	 // Check all the checkboxes
         function checkall()
         {
             var table_id = "table#<?php echo $option['table_name']; ?>";
@@ -377,13 +349,16 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
                         });
                         var ocs = [];
                         //Add the actual $_POST to the $_POST of the ajax request
-    <?php
-    foreach ($protectedPost as $key => $value) {
-        if (!is_array($value)) {
-            echo "d['" . $key . "'] = '" . $value . "'; \n";
-        }
-    }
-    ?>
+						<?php
+						foreach ($protectedPost as $key => $value) {
+							if (!is_array($value)) {
+								echo "d['" . $key . "'] = '" . $value . "'; \n";
+							}
+							if($key == "visible_col") {
+								$visible_col = $value;
+							}
+						}
+						?>
                         ocs.push($(form_name).serialize());
                         d.visible_col = visible;
                         d.ocs = ocs;
@@ -411,8 +386,8 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
                     data.search.search = "";
                     data.start = 0;
                 },
-								"conditionalPaging": true,
-								"lengthMenu": [ 10, 25, 50, 100, 250, 500, 1000],
+				"conditionalPaging": true,
+				"lengthMenu": [ 10, 25, 50, 100, 250, 500, 1000],
                 //Column definition
                 "columns": [
     <?php
@@ -422,7 +397,7 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
     // Unset visible columns session var
     unset($_SESSION['OCS']['visible_col'][$option['table_name']]);
 
-//Visibility handling
+	//Visibility handling
     foreach ($columns as $key => $column) {
         if (!empty($visible_col)) {
             if ((in_array($index, $visible_col))) {
@@ -434,8 +409,7 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
             }
             $index ++;
         } else {
-            if (( (in_array($key, $default_fields)) || (in_array($key, $list_col_cant_del)) || array_key_exists($key, $default_fields) || ($key == "ACTIONS" )) && !(in_array($key, $actions))
-            ) {
+            if (( (in_array($key, $default_fields)) || (in_array($key, $list_col_cant_del)) || array_key_exists($key, $default_fields) || ($key == "ACTIONS" )) && !(in_array($key, $actions))) {
                 // add visibles columns
                 $_SESSION['OCS']['visible_col'][$option['table_name']][$key] = $column;
                 $visible = 'true';
@@ -504,8 +478,8 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
             $("#select_col" + table_name).change(function () {
                 var col = "." + $(this).val();
                 $(table_id).DataTable().column(col).visible(!($(table_id).DataTable().column(col).visible()));
-                $(table_id).DataTable().ajax.reload();
-                $("#select_col" + table_name).val('default');
+				$(table_id).DataTable().ajax.reload();
+				$("#select_col" + table_name).val('default');
             });
 
             //$("<span id='" + table_name + "_settings_toggle' class='glyphicon glyphicon-chevron-down table_settings_toggle'></span>").hide().appendTo("#" + table_name + "_filter label");
@@ -577,7 +551,11 @@ function ajaxtab_entete_fixe($columns, $default_fields, $option = array(), $list
     echo "<input type='hidden' id='CONFIRM_CHECK' name='CONFIRM_CHECK' value=''>";
     echo "<input type='hidden' id='OTHER_BIS' name='OTHER_BIS' value=''>";
     echo "<input type='hidden' id='OTHER_TER' name='OTHER_TER' value=''>";
-
+	echo "<input type='hidden' id='EDIT_DEPLOY' name='EDIT_DEPLOY' value=''>";
+	echo "<input type='hidden' id='SHOW_DETAILS' name='SHOW_DETAILS' value=''>";
+	echo "<input type='hidden' id='ARCHIVER' name='ARCHIVER' value=''>";
+	echo "<input type='hidden' id='RESTORE' name='RESTORE' value=''>";
+	
     if ($_SESSION['OCS']['DEBUG'] == 'ON') {
         ?><center>
             <div id="<?php echo $option['table_name']; ?>_debug" class="alert alert-info" role="alert">
@@ -1378,6 +1356,9 @@ function ajaxfiltre($queryDetails,$tab_options){
 
 						$rang =0;
 						foreach($tab_options['visible_col'] as $index=>$column){
+							if($tab_options['columns'][$column]['name'] == $tab_options['NO_SEARCH'][$tab_options['columns'][$column]['name']]){
+								$tab_options['columns'][$column]['searchable'] = false;
+							}
 							$searchable =  ($tab_options['columns'][$column]['searchable'] == "true") ? true : false;
 							$name = preg_replace("/[^A-Za-z0-9\._]/", "", $tab_options['columns'][$column]['name']);
 							if (!empty($tab_options["replace_query_arg"][$name])){
@@ -1389,24 +1370,21 @@ function ajaxfiltre($queryDetails,$tab_options){
 							if (!empty($tab_options['NO_SEARCH'][$tab_options['columns'][$column]['name']])){
 								$searchable = false;
 							}
+							
 							if ($searchable){
 
-								// if search in column selected
-								if (!empty($tab_options['COL_SEARCH']) && $tab_options['COL_SEARCH'] != 'default' && $rang == 0) {
-										$name_col = preg_replace("/[^A-Za-z0-9\._]/", "", $tab_options['COL_SEARCH']);
-										$filtertxt =  " HAVING (( ".$name_col." LIKE '%%".$search."%%' ) ";
-								} else if ($name != 'c' && $tab_options['COL_SEARCH'] == 'default') {
-										if ($rang == 0){
-											$filtertxt =  " HAVING (( ".$name." LIKE '%%".$search."%%' ) ";
-										} else {
-											$filtertxt .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
-										}
+								if ($name != 'c' && $tab_options['COL_SEARCH'] == 'default') {
+									if ($rang == 0){
+										$filtertxt =  " HAVING (( ".$name." LIKE '%%".$search."%%' ) ";
+									} else {
+										$filtertxt .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
+									}
 								} else if (empty($tab_options["COL_SEARCH"])) {
-										if ($rang == 0){
-											$filtertxt =  " HAVING (( ".$name." LIKE '%%".$search."%%' ) ";
-										} else {
-											$filtertxt .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
-										}
+									if ($rang == 0){
+										$filtertxt =  " HAVING (( ".$name." LIKE '%%".$search."%%' ) ";
+									} else {
+										$filtertxt .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
+									}
 								}
 								$rang++;
 							}
@@ -1419,7 +1397,7 @@ function ajaxfiltre($queryDetails,$tab_options){
 					}
 					else {
 						if($key>1){
-						 $queryDetails.=" ".$word." ".$row;
+						 	$queryDetails.=" ".$word." ".$row;
 						}else{
 							$queryDetails = $row;
 						}
@@ -1429,31 +1407,137 @@ function ajaxfiltre($queryDetails,$tab_options){
 				return $queryDetails;
 			}
 		}
-		//REQUET SELECT FROM
+
+		// Check if at least one of the column used in the query if full-text indexed
+		foreach ($tab_options['visible_col'] as $column) {
+			if ($tab_options['columns'][$column]['ft_index'] == 'true') {
+				// Find the correct place where to do the full-text search in the query
+				if (count($sqlword['WHERE'])>1) {
+						$ft_queryDetails1 = $sqlword['WHERE'][0];
+						$ft_queryDetails2 = $sqlword['WHERE'][1];
+						$ft_place = 'WHERE';
+				} elseif (count($sqlword['GROUPBY'])>1) {
+						$ft_queryDetails1 = $sqlword['GROUPBY'][0];
+						$ft_queryDetails2 = $sqlword['GROUPBY'][1];
+						$ft_place = 'GROUP BY';
+				}
+				break;
+			}
+		}
+
+		// Add filtering criteria
+		if (!empty($ft_place)) {
+
+			// Search with at least 1 full-text indexed columns
+			$index = 0;
+
+			foreach ($tab_options['visible_col'] as $column) {
+				$cname = $tab_options['columns'][$column]['name'];
+
+				// Find out if the column is searchable
+				if($tab_options['columns'][$column]['name'] == $tab_options['NO_SEARCH'][$tab_options['columns'][$column]['name']]){
+					$tab_options['columns'][$column]['searchable'] = false;
+				}
+				$searchable =  ($tab_options['columns'][$column]['searchable'] == "true") ? true : false;
+
+				// Find out if the column is searchable and is full-text indexed
+				if ($searchable && $tab_options['columns'][$column]['ft_index'] == 'true') {
+					// Add a '+' in front of, and a '*' at the end of, each work  when $search contains several words
+					$search = trim($search);
+					if (stripos($search, ' ') !== false) {
+							$search1 = '+'.implode(' +', explode(' ',$search));
+							$search1  = implode(explode(' ',$search1),'* ')."*";
+					} else {
+							$search1 = $search . "*";
+					}
+					// Append the search term
+					if ($index==0) {
+							$ft_queryDetails1 .= " WHERE (MATCH ($cname) AGAINST ('$search1' IN BOOLEAN MODE)";
+					} else {
+							$ft_queryDetails1 .= " OR MATCH ($cname) AGAINST ('$search1' IN BOOLEAN MODE)";
+					}
+					$index++;
+				} elseif ($searchable && $tab_options['columns'][$column]['ft_index'] == 'false') {
+					// Column is searchable but isn't full-text indexed
+					if ($index==0) {
+							$ft_queryDetails1 .= " WHERE ( $cname LIKE '%%$search%%')";
+					} else {
+							$ft_queryDetails1 .= " OR $cname LIKE '%%$search%%')";
+					}
+					$index++;
+				}
+			}
+
+			// Close the full-text search clause if we added any
+			if ($index>0) {
+				if ($ft_place == 'WHERE') {
+					$queryDetails = $ft_queryDetails1 . ") AND " . $ft_queryDetails2;
+				} else {
+					$queryDetails = $ft_queryDetails1 . ") GROUP BY " . $ft_queryDetails2;
+				}
+			}
+
+			return $queryDetails;
+		}
+
+		// REQUEST SELECT FROM
 		$queryDetails .= " HAVING ";
 		$index =0;
 		foreach($tab_options['visible_col'] as $column){
+			$cname = $tab_options['columns'][$column]['name'];
+			$account_select = null;
+
+			// Special treatment if accountinfo select type
+			if (substr($cname,0,2) == 'a.'){
+				require_once('require/function_admininfo.php');
+				$id_tag=explode('_',substr($cname,2));
+				if($id_tag[0] != 'TAG') {
+					$info_tag = find_info_accountinfo($id_tag[1]);
+					if($info_tag[$id_tag[1]]['type'] == 2) {
+						$info = find_value_field('ACCOUNT_VALUE_' . $info_tag[$id_tag[1]]['name']);
+						foreach($info as $key => $value) {
+							if(strpos($value, $search) !== false) {
+								$acc_select[$key] = $key;
+							}
+						}
+						if($acc_select != null) {
+							$account_select = implode(',', $acc_select);
+						}
+					}
+				}
+			}
+
+			// (Cyrille: The following 2 tests are used at least 3 times in this file. Wouldn't it be a good time to create a function?)
+			if($tab_options['columns'][$column]['name'] == $tab_options['NO_SEARCH'][$tab_options['columns'][$column]['name']]){
+				$tab_options['columns'][$column]['searchable'] = false;
+			}
 			$searchable =  ($tab_options['columns'][$column]['searchable'] == "true") ? true : false;
+
+			// (Cyrille: What the hell is the purpose of this "HAVING" array?)
 			if(is_array($tab_options['HAVING'])&&isset($tab_options['HAVING'][$column])){
 				$searchable =true;
 			}
 
-			if ($searchable){
-				$name = $tab_options['columns'][$column]['name'];
-				if (!empty($tab_options['COL_SEARCH']) && $tab_options['COL_SEARCH'] != 'default' && $index == 0) {
-						$name_col = $tab_options['COL_SEARCH'];
-						$filter =  " (( ".$name_col." LIKE '%%".$search."%%' ) ";
-				} else if ($name != 'c' && $tab_options['COL_SEARCH'] == 'default') {
+			// if account info select -> change comparator
+			if($account_select != null) {
+				$search_arg = "IN (".$account_select.")";
+			} else {
+				$search_arg = "LIKE '%%".$search."%%'";
+			}
+
+			// If column is searchable and doesn't have a full-text index 
+			if ($searchable && (empty($tab_options['columns'][$column]['ft_index']) || $tab_options['columns'][$column]['ft_index'] == 'false')) {
+				if ($cname != 'c' && $tab_options['COL_SEARCH'] == 'default') {
 						if ($index == 0){
-							$filter =  " (( ".$name." LIKE '%%".$search."%%' ) ";
+							$filter =  " (( ".$cname." ".$search_arg." ) ";
 						} else {
-							$filter .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
+							$filter .= " OR  ( ".$cname." ".$search_arg." ) ";
 						}
 				} else if (empty($tab_options["COL_SEARCH"])) {
 						if ($index == 0){
-							$filter =  " (( ".$name." LIKE '%%".$search."%%' ) ";
+							$filter =  " (( ".$cname." ".$search_arg." ) ";
 						} else {
-							$filter .= " OR  ( ".$name." LIKE '%%".$search."%%' ) ";
+							$filter .= " OR  ( ".$cname." ".$search_arg." ) ";
 						}
 				}
 				$index++;
@@ -1473,49 +1557,47 @@ function ajaxfiltre($queryDetails,$tab_options){
 * 						'Option' => value,
 * 						}
 */
-function ajaxsort(&$tab_options){
-	if ($tab_options['columns'][$tab_options['order']['0']['column']]['orderable'] == "true"){
-		$name = $tab_options['columns'][$tab_options['order']['0']['column']]['name'];
+function ajaxsort(&$tab_options) {
+	$tri = '';
+	$tab_iplike = array('H.IPADDR','IPADDRESS','IP','IPADDR','IP_MIN','IP_MAX');
 
-		if (!empty($tab_options["replace_query_arg"][$name])){
-			$name= $tab_options["replace_query_arg"][$name];
-		}
-		$tri = $name;
-		$sens = $tab_options['order']['0']['dir'];
-	} else if ($tab_options['columns']) {
-		foreach($tab_options['columns'] as $column){
-			if ($column['orderable']=="true"){
-				$tri = $column['name'];
-				$sens = "asc";
-				break;
+	if ($tab_options['columns'][$tab_options['order']['0']['column']]['orderable'] == "true") {
+		// reset
+		foreach ($tab_options['order'] as $index => $v ) {
+			// get column name
+			$name = $tab_options['columns'][$tab_options['order'][$index]['column']]['name'];
+
+			if (!empty($tab_options["replace_query_arg"][$name])) {
+				$name = $tab_options["replace_query_arg"][$name];
+			}
+			// field name is IP format alike
+			if (in_array(mb_strtoupper($name),$tab_iplike)) {
+				$tri .= " INET_ATON(".$name.") ".$v['dir'].", ";
+			} else if($tab_options['TRI']['DATE'][$name]) {
+				if(isset($tab_options['ARG_SQL'])) {
+					$tri .= " STR_TO_DATE(%s,'%s') %s";
+					$tab_options['ARG_SQL'][] = $name;
+					$tab_options['ARG_SQL'][] = $tab_options['TRI']['DATE'][$name];
+					$tab_options['ARG_SQL'][] = $v['dir'];
+				} else {
+					$tri .= " STR_TO_DATE(".$name.",'".$tab_options['TRI']['DATE'][$name]."') ".$v['dir'];
+				}
+			} else {
+				if ( strpos($name,".") === false ) {
+					$tri .= "".$name." ".$v['dir'].", ";
+				} else {
+					$tri .= $name . " ".$v['dir'].", ";
+				}
 			}
 		}
-	}
-	$sort ="";
-	if (!empty($tri) && !empty($sens)){
-	$tab_iplike=array('H.IPADDR','IPADDRESS','IP','IPADDR');
-	if (in_array(mb_strtoupper($tri),$tab_iplike)){
-		$sort= " order by INET_ATON(".$tri.") ".$sens;
-	}elseif ($tab_options['TRI']['SIGNED'][$tri]){
-		$sort= " order by cast(".$$tri." as signed) ".$sens;
-	}
-	elseif($tab_options['TRI']['DATE'][$tri]){
-
-		if(isset($tab_options['ARG_SQL'])){
-			$sort =" order by STR_TO_DATE(%s,'%s') %s";
-			$tab_options['ARG_SQL'][]=$tri;
-			$tab_options['ARG_SQL'][]=$tab_options['TRI']['DATE'][$tri];
-			$tab_options['ARG_SQL'][]=$sens;
-		}else{
-			$sort= " order by STR_TO_DATE(".$tri.",'".$tab_options['TRI']['DATE'][$tri]."') ".$sens;
-		}
-	}else{
-		$sort= " order by ".$tri." ".$sens;
+		$tri = rtrim($tri, ", ");
 	}
 
+	if($tri != "") {
+		return " order by ".$tri;
+	} else {
+		return "";
 	}
-	return $sort;
-
 }
 
 //fonction qui retourne un string contenant le bloc généré LIMIT de la requete
@@ -1619,7 +1701,7 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 						}
 						break;
 					case "GROUP_NAME":
-						$row['NAME']="<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_group_show']."&head=1&systemid=".$row['ID']."' target='_blank'>".$value_of_field."</a>";
+						$row['NAME']="<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_group_show']."&head=1&systemid=".$row['ID']."'>".$value_of_field."</a>";
 						break;
 					case "NULL":
 						$row[$key]="&nbsp";
@@ -1641,7 +1723,7 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 						$row[$key]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_stats']."&head=1&stat=".$value_of_field."\"><span class='glyphicon glyphicon-stats' title='".$l->g(1251)."'></span></a>";
 						break;
 					case "ACTIVE":
-						$row[$key]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_popup_active']."&head=1&active=".$value_of_field."\"><span class='glyphicon glyphicon-share' title='".$l->g(431)."'></span></a>";
+						$row[$key]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_popup_active']."&head=1&active=".$value_of_field."\"><span class='glyphicon glyphicon-ok' title='".$l->g(431)."'></span></a>";
 						break;
 					case "SHOWACTIVE":
 						if(!empty($tab_options['SHOW_ONLY'][$key][$row['FILEID']])){
@@ -1660,6 +1742,24 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 							$row[$key]="<center><a href='index.php?".PAG_INDEX."=".$pages_refs['ms_custom_perim']."&head=1&id=".$value_of_field."' ><span class='glyphicon glyphicon-edit'></span></a><center>";
 						}
 						break;
+					case "EDIT_DEPLOY":
+						$row[$key]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_package']."&head=1&package=".$value_of_field."\"><span class='glyphicon glyphicon-edit'></span></a>";
+						break;
+					case "SHOW_DETAILS":
+						$row[$key]='<a href="#'.$value_of_field.'" data-toggle="modal" data-target="#'.$value_of_field.'" title="'.$l->g(9013).'"><span class="glyphicon glyphicon-search"></span></a>';
+						break;
+					case "ARCHIVER":
+						if ($value_of_field!= '&nbsp;'){
+							$lbl_msg=$l->g(1550)." ".$value_of_field;
+							$row[$key]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"ARCHIVER\",\"".htmlspecialchars($lbl_msg, ENT_QUOTES)."\");'><span class='glyphicon glyphicon-save' title='".$l->g(1551)."'></span></a>";
+						}	
+						break;
+					case "RESTORE":
+						if ($value_of_field!= '&nbsp;'){
+							$lbl_msg=$l->g(1553)." ".$value_of_field;
+							$row[$key]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"RESTORE\",\"".htmlspecialchars($lbl_msg, ENT_QUOTES)."\");'><span class='glyphicon glyphicon-open' title='".$l->g(1552)."'></span></a>";
+						}	
+						break;
 					default :
 						if (substr($key,0,11) == "PERCENT_BAR"){
 							//require_once("function_graphic.php");
@@ -1698,6 +1798,9 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 							$row[$column]=$tab_options['REPLACE_VALUE_ALL_TIME'][$key][$row[$tab_options['FIELD_REPLACE_VALUE_ALL_TIME']]];
 						}
 						if (!empty($tab_options['LIEN_LBL'][$key])){
+							if(strpos($row[$tab_options['LIEN_CHAMP'][$key]], '+')){
+								$row[$tab_options['LIEN_CHAMP'][$key]] = str_replace("+", "%2B", $row[$tab_options['LIEN_CHAMP'][$key]]);
+							}
 							$row[$column]= "<a href='".$tab_options['LIEN_LBL'][$key].$row[$tab_options['LIEN_CHAMP'][$key]]."'>".$value_of_field."</a>";
 						}
 						if (!empty($tab_options['REPLACE_COLUMN_KEY'][$key])){
@@ -1719,10 +1822,14 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 			}
 			$actions = array(
 				"MODIF",
+				"EDIT_DEPLOY",
 				"SUP",
 				"ZIP",
 				"STAT",
 				"ACTIVE",
+				"SHOW_DETAILS",
+				"ARCHIVER",
+				"RESTORE",
 			);
 			foreach($actions as $action){
 				$row['ACTIONS'].= " ".$row[$action];
@@ -1781,15 +1888,23 @@ function tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$
 			"ACTIVE",
 			"MAC",
 			"MD5_DEVICEID",
+			"EDIT_DEPLOY",
+			"SHOW_DETAILS",
+			"ARCHIVER",
+			"RESTORE",
 	);
 
 
 	$actions = array(
 				"MODIF",
+				"EDIT_DEPLOY",
 				"SUP",
 				"ZIP",
 				"STAT",
 				"ACTIVE",
+				"SHOW_DETAILS",
+				"ARCHIVER",
+				"RESTORE",
 	);
 	foreach($actions as $action){
 		if(isset($list_fields[$action])){
@@ -1942,344 +2057,6 @@ function tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$
 	echo json_encode($res);
 }
 
-
-
-
-
-
-
-
-
-
-
-//fonction qui permet de gérer les données à afficher dans le tableau
-function gestion_donnees($sql_data,$list_fields,$tab_options,$form_name,$default_fields,$list_col_cant_del,$queryDetails,$table_name){
-	global $l,$protectedPost,$pages_refs;
-
-	//p($tab_options['REPLACE_VALUE_ALL_TIME']);
-	$_SESSION['OCS']['list_fields'][$table_name]=$list_fields;
-	//requete de condition d'affichage
-	//attention: la requete doit etre du style:
-	//select champ1 AS FIRST from table where...
-	if (isset($tab_options['REQUEST'])){
-		foreach ($tab_options['REQUEST'] as $field_name => $value){
-			$tab_condition[$field_name]=array();
-			$resultDetails = mysql2_query_secure($value, $_SESSION['OCS']["readServer"],$tab_options['ARG'][$field_name]);
-			while($item = mysqli_fetch_object($resultDetails)){
-				$tab_condition[$field_name][$item -> FIRST]=$item -> FIRST;
-			}
-		}
-	}
-	if (isset($sql_data)){
-		foreach ($sql_data as $i=>$donnees){
-			foreach($list_fields as $key=>$value){
-				$htmlentities=true;
-				$truelabel=$key;
-			//	p($tab_options);
-				//gestion des as de colonne
-				if (isset($tab_options['AS'][$value]))
-				$value=$tab_options['AS'][$value];
-				//echo $value."<br>";
-				$num_col=$key;
-				if ($default_fields[$key])
-				$correct_list_fields[$num_col]=$num_col;
-				if ($list_col_cant_del[$key])
-				$correct_list_col_cant_del[$num_col]=$num_col;
-				$alias=explode('.',$value);
-				if (isset($alias[1])){
-					$no_alias_value=$alias[1];
-				}else
-				 	$no_alias_value=$value;
-
-				//echo $no_alias_value;
-				//si aucune valeur, on affiche un espace
-				if ($donnees[$no_alias_value] == ""){
-					$value_of_field = "&nbsp";
-					$htmlentities=false;
-				}else //sinon, on affiche la valeur
-				{
-					$value_of_field=$donnees[$no_alias_value];
-				}
-
-				//utf8 or not?
-				//$value_of_field=data_encode_utf8($value_of_field);
-
-				$col[$i]=$key;
-				if ($protectedPost['sens_'.$table_name] == "ASC")
-					$sens="DESC";
-				else
-					$sens="ASC";
-
-				$affich='OK';
-				//on n'affiche pas de lien sur les colonnes non présentes dans la requete
-				if (isset($tab_options['NO_TRI'][$key]))
-					$lien='KO';
-				else
-					$lien='OK';
-
-				if (isset($tab_options['REPLACE_VALUE_ALL_TIME'][$key])){
-					if (isset($tab_options['FIELD_REPLACE_VALUE_ALL_TIME']))
-						$value_of_field=$tab_options['REPLACE_VALUE_ALL_TIME'][$key][$donnees[$tab_options['FIELD_REPLACE_VALUE_ALL_TIME']]];
-					else
-						$value_of_field=$tab_options['REPLACE_VALUE_ALL_TIME'][$key][$donnees['ID']];
-				}
-
-
-
-				if (isset($tab_options['REPLACE_VALUE'][$key])){
-					//if multi value, $temp_val[1] isset
-					$temp_val=explode('&&&',$value_of_field);
-					$multi_value=0;
-					$temp_value_of_field="";
-					while (isset($temp_val[$multi_value])){
-						$temp_value_of_field.=$tab_options['REPLACE_VALUE'][$key][$temp_val[$multi_value]]."<br>";
-						$multi_value++;
-					}
-					$temp_value_of_field=substr($temp_value_of_field,0,-4);
-					$value_of_field=$temp_value_of_field;
-				}
-				if (isset($tab_options['REPLACE_WITH_CONDITION'][$key][$value_of_field])){
-					if (!is_array($tab_options['REPLACE_WITH_CONDITION'][$key][$value_of_field]))
-						$value_of_field= $tab_options['REPLACE_WITH_CONDITION'][$key][$value_of_field];
-					else{
-						foreach ($tab_options['REPLACE_WITH_CONDITION'][$key][$value_of_field] as $condition=>$condition_value){
-							if ($donnees[$condition] == '' or is_null($donnees[$condition]))
-							{
-								$value_of_field=$condition_value;
-							}
-						}
-
-					}
-				}
-
-				if (isset($tab_options['REPLACE_WITH_LIMIT']['UP'][$key])){
-					if ($value_of_field > $tab_options['REPLACE_WITH_LIMIT']['UP'][$key])
-						$value_of_field= $tab_options['REPLACE_WITH_LIMIT']['UPVALUE'][$key];
-				}
-
-				if (isset($tab_options['REPLACE_WITH_LIMIT']['DOWN'][$key])){
-					if ($value_of_field < $tab_options['REPLACE_WITH_LIMIT']['DOWN'][$key])
-						$value_of_field = $tab_options['REPLACE_WITH_LIMIT']['DOWNVALUE'][$key];
-				}
-
-				unset($key2);
-				if (isset($tab_condition[$key])){
-						if ((!$tab_condition[$key][$donnees[$tab_options['FIELD'][$key]]] and !$tab_options['EXIST'][$key])
-							or ($tab_condition[$key][$donnees[$tab_options['FIELD'][$key]]] and $tab_options['EXIST'][$key])){
-							if ($key == "STAT" or $key == "SUP" or $key == "CHECK"){
-								$key2 = "NULL";
-							}else{
-								$data[$i][$num_col]=$value_of_field;
-								$affich="KO";
-							}
-						}
-				}
-				//if (!isset($entete[$num_col])){
-					if (!isset($tab_options['LBL'][$key])){
-						$entete[$num_col]=$key;
-					}else
-						$entete[$num_col]=$tab_options['LBL'][$key];
-				//}
-
-				if (isset($tab_options['NO_LIEN_CHAMP']['SQL'][$key])){
-					$exit=false;
-					foreach ($tab_options['NO_LIEN_CHAMP']['SQL'][$key] as $id=>$sql_rest){
-						$sql=$sql_rest;
-						if (isset($tab_options['NO_LIEN_CHAMP']['ARG'][$id][$key]))
-							$arg=$donnees[$tab_options['NO_LIEN_CHAMP']['ARG'][$id][$key]];
-						else
-							$arg="";
-						$result_lien = mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
-						if ($item = mysqli_fetch_object($result_lien)){
-						  $data[$i][$num_col]="<a href='".$tab_options['LIEN_LBL'][$key][$id].$donnees[$tab_options['LIEN_CHAMP'][$key][$id]]."' target='_blank'>".$value_of_field."</a>";
-						 // $exit=true;
-						 break;
-						}else
-						echo 'toto';
-
-
-					}
-				}
-
-				//si un lien doit être mis sur le champ
-				//l'option $tab_options['NO_LIEN_CHAMP'] empêche de mettre un lien sur certaines
-				//valeurs du champs
-				//exemple, si vous ne voulez pas mettre un lien si le champ est 0,
-				//$tab_options['NO_LIEN_CHAMP'][$key] = array(0);
-				if (isset($tab_options['LIEN_LBL'][$key]) and !is_array($tab_options['LIEN_LBL'][$key])
-					and (!isset($tab_options['NO_LIEN_CHAMP'][$key]) or !in_array($value_of_field,$tab_options['NO_LIEN_CHAMP'][$key]))){
-					$affich="KO";
-
-					if (!isset($tab_options['LIEN_TYPE'][$key])){
-						$data[$i][$num_col]="<a href='".$tab_options['LIEN_LBL'][$key].$donnees[$tab_options['LIEN_CHAMP'][$key]]."' target='_blank'>".$value_of_field."</a>";
-					}else{
-						if (!isset($tab_options['POPUP_SIZE'][$key]))
-						$size="width=550,height=350";
-						else
-						$size=$tab_options['POPUP_SIZE'][$key];
-						$data[$i][$num_col]="<a href=\"".$tab_options['LIEN_LBL'][$key].$donnees[$tab_options['LIEN_CHAMP'][$key]]."\")>".$value_of_field."</a>";
-
-					}
-				}
-
-
-				if (isset($tab_options['JAVA']['CHECK'])){
-						$javascript="OnClick='confirme(\"".htmlspecialchars($donnees[$tab_options['JAVA']['CHECK']['NAME']], ENT_QUOTES)."\",".$value_of_field.",\"".$form_name."\",\"CONFIRM_CHECK\",\"".htmlspecialchars($tab_options['JAVA']['CHECK']['QUESTION'], ENT_QUOTES)." \")'";
-				}else
-						$javascript="";
-
-				//si on a demander un affichage que sur certaine ID
-				if (is_array($tab_options) and !$tab_options['SHOW_ONLY'][$key][$value_of_field] and $tab_options['SHOW_ONLY'][$key]){
-					$key = "NULL";
-				}
-
-				if (isset($tab_options['COLOR'][$key])){
-					$value_of_field="<font color=".$tab_options['COLOR'][$key].">".$value_of_field."</font>";
-					$htmlentities=false;
-				}
-				if ($affich == 'OK'){
-
-					$lbl_column=array("SUP"=>$l->g(122),
-									  "MODIF"=>$l->g(115),
-									  "CHECK"=>$l->g(1119) . "<input type='checkbox' name='ALL' id='ALL' Onclick='checkall();'>");
-					if (!isset($tab_options['NO_NAME']['NAME']))
-							$lbl_column["NAME"]=$l->g(23);
-					//modify lbl of column
-					if (!isset($entete[$num_col])
-						or ($entete[$num_col] == $key and !isset($tab_options['LBL'][$key]))){
-						if (array_key_exists($key,$lbl_column))
-							$entete[$num_col]=$lbl_column[$key];
-						else
-							$entete[$num_col]=$truelabel;
-					}
-					if ($key == "NULL" or isset($key2)){
-						$data[$i][$num_col]="&nbsp";
-						$lien = 'KO';
-					}elseif ($key == "GROUP_NAME"){
-						$data[$i][$num_col]="<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_group_show']."&head=1&systemid=".$donnees['ID']."' target='_blank'>".$value_of_field."</a>";
-					}elseif ($key == "SUP" and $value_of_field!= '&nbsp;'){
-						if (isset($tab_options['LBL_POPUP'][$key])){
-							if (isset($donnees[$tab_options['LBL_POPUP'][$key]]))
-								$lbl_msg=$l->g(640)." ".$donnees[$tab_options['LBL_POPUP'][$key]];
-							else
-								$lbl_msg=$tab_options['LBL_POPUP'][$key];
-						}else
-							$lbl_msg=$l->g(640)." ".$value_of_field;
-						$data[$i][$num_col]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"SUP_PROF\",\"".htmlspecialchars($lbl_msg, ENT_QUOTES)."\");'><img src=image/delete-small.png></a>";
-						$lien = 'KO';
-					}elseif ($key == "MODIF"){
-						$data[$i][$num_col]="<a href=# OnClick='pag(\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"MODIF\",\"".$form_name."\");'><span class='glyphicon glyphicon-edit'></span></a>";
-						$lien = 'KO';
-					}elseif ($key == "SELECT"){
-						$data[$i][$num_col]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"SELECT\",\"".htmlspecialchars($tab_options['QUESTION']['SELECT'],ENT_QUOTES)."\");'><img src=image/prec16.png></a>";
-						$lien = 'KO';
-					}elseif ($key == "OTHER"){
-						$data[$i][$num_col]="<a href=#  OnClick='pag(\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"OTHER\",\"".$form_name."\");'><img src=image/red.png></a>";
-						$lien = 'KO';
-					}elseif ($key == "ZIP"){
-						$data[$i][$num_col]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_compress']."&no_header=1&timestamp=".$value_of_field."&type=".$tab_options['TYPE']['ZIP']."\"><span class='glyphicon glyphicon-download-alt' title='".$l->g(2120)."'></span></a>";
-						$lien = 'KO';
-					}
-					elseif ($key == "STAT"){
-						$data[$i][$num_col]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_stats']."&head=1&stat=".$value_of_field."\"><span class='glyphicon glyphicon-stats'></span></a>";
-						$lien = 'KO';
-					}elseif ($key == "ACTIVE"){
-						$data[$i][$num_col]="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_tele_popup_active']."&head=1&active=".$value_of_field."\"><span class='glyphicon glyphicon-share' title='".$l->g(431)."'></span></a>";
-						$lien = 'KO';
-					}elseif ($key == "SHOWACTIVE"){
-						$data[$i][$num_col]="<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_tele_actives']."&head=1&timestamp=".$donnees['FILEID']."' target=_blank>".$value_of_field."</a>";
-					}
-					elseif ($key == "CHECK" and $value_of_field!= '&nbsp;'){
-						$data[$i][$num_col]="<input type='checkbox' name='check".$value_of_field."' id='check".$value_of_field."' ".$javascript." ".(isset($protectedPost['check'.$value_of_field])? " checked ": "").">";
-						$lien = 'KO';
-					}
-					elseif ($key == "NAME" and !isset($tab_options['NO_NAME']['NAME'])){
-							$link_computer="index.php?".PAG_INDEX."=".$pages_refs['ms_computer']."&head=1";
-							if ($donnees['ID'])
-								$link_computer.="&systemid=".$donnees['ID'];
-							if ($donnees['MD5_DEVICEID'])
-								$link_computer.= "&crypt=".$donnees['MD5_DEVICEID'];
-							$data[$i][$num_col]="<a href='".$link_computer."'  target='_blank'>".$value_of_field."</a>";
-					}elseif ($key == "MAC"){
-						//echo substr($value_of_field,0,8);
-						//echo $_SESSION['OCS']["mac"][substr($value_of_field,0,8)];
-						if (isset($_SESSION['OCS']["mac"][mb_strtoupper(substr($value_of_field,0,8))]))
-						$constr=$_SESSION['OCS']["mac"][mb_strtoupper(substr($value_of_field,0,8))];
-						else
-						$constr="<font color=red>".$l->g(885)."</font>";
-						//echo "=>".$constr."<br>";
-						$data[$i][$num_col]=$value_of_field." (<small>".$constr."</small>)";
-					}elseif (substr($key,0,11) == "PERCENT_BAR"){
-						require_once("function_graphic.php");
-						$data[$i][$num_col]="<CENTER>".percent_bar($value_of_field)."</CENTER>";
-						//$lien = 'KO';
-					}
-					else{
-						if (isset($tab_options['OTHER'][$key][$value_of_field])){
-							$end="<a href=# OnClick='pag(\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"OTHER\",\"".$form_name."\");'><img src=".$tab_options['OTHER']['IMG']."></a>";
-						}elseif (isset($tab_options['OTHER_BIS'][$key][$value_of_field])){
-							$end="<a href=# OnClick='pag(\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"OTHER_BIS\",\"".$form_name."\");'><img src=".$tab_options['OTHER_BIS']['IMG']."></a>";
-						}elseif (isset($tab_options['OTHER_TER'][$key][$value_of_field])){
-							$end="<a href=# OnClick='pag(\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"OTHER_TER\",\"".$form_name."\");'><img src=".$tab_options['OTHER_TER']['IMG']."></a>";
-						}else{
-							$end="";
-						}
-						if ($htmlentities)
-							//$value_of_field=htmlentities($value_of_field,ENT_COMPAT,'UTF-8');
-							$value_of_field=strip_tags_array($value_of_field);
-
-						$data[$i][$num_col]=$value_of_field.$end;
-
-					}
-
-				}
-
-				if ($lien == 'OK'){
-					$deb="<a onclick='return tri(\"".$value."\",\"tri_".$table_name."\",\"".$sens."\",\"sens_".$table_name."\",\"".$form_name."\");' >";
-					$fin="</a>";
-					$entete[$num_col]=$deb.$entete[$num_col].$fin;
-					if ($protectedPost['tri_'.$table_name] == $value){
-						if ($protectedPost['sens_'.$table_name] == 'ASC')
-							$img="<img src='image/down.png'>";
-						else
-							$img="<img src='image/up.png'>";
-						$entete[$num_col]=$img.$entete[$num_col];
-					}
-				}
-
-			}
-
-
-		}
-		if ($tab_options['UP']){
-			$i=0;
-			while($data[$i]){
-				foreach ($tab_options['UP'] as $key=>$value){
-					if ($data[$i][$key] == $value){
-						$value_temp=$data[$i];
-						unset($data[$i]);
-					}
-				}
-				$i++;
-			}
-			array_unshift ($data, $value_temp);
-		}
-	//	echo $protectedPost['tri_'.$table_name];
-	//	echo "<br><hr>";
-		//p($tab_options['REPLACE_VALUE']);
-		if(isset($tab_options['REPLACE_VALUE'][$protectedPost['tri_'.$table_name]])){
-			//p($data);
-//echo "<br><hr><br>";
-			if ($protectedPost['sens_repart_tag'] == 'ASC')
-				asort($data);
-			else
-				arsort($data);
-			//	p($data);
-		}
-	 return array('ENTETE'=>$entete,'DATA'=>$data,'correct_list_fields'=>$correct_list_fields,'correct_list_col_cant_del'=>$correct_list_col_cant_del);
-	}else
-	return false;
-}
 function del_selection($form_name){
 	global $l;
 ?>
