@@ -82,23 +82,25 @@ function time_deploy($label = '') {
     formGroup('text', 'TPS', $label, '10', '', '', '', '', '', $champ);
 }
 
-function input_pack_taille($name, $other_field, $size, $input_size, $input_value, $label = '', $addon = '') {
-    javascript_pack();
-    if ($size > 1024) {
-        $champ = '	onKeyPress="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
-		 			onkeydown="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
-		 			onkeyup="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
-		  			onblur="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
-		  			onclick="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
-				';
+function input_pack_taille($name, $other_field, $size, $input_size, $input_value, $label = '', $addon = '', $modif = true) {
+    if ($size > 1024 && $modif == true) {
+        $champ = ' onKeyPress="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
+                   onkeydown="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
+                   onkeyup="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
+                   onblur="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
+                   onclick="maj(\'' . $name . '\', \'' . $other_field . '\', \'' . $size . '\');"
+                   ';
+    } elseif($modif == false) {
+        $champ = " style='pointer-events:none; background:lightgrey;' ";
     } else {
-        $champ = " value=1 disable='disable' ";
+        $champ = " style='pointer-events:none; background:lightgrey;' ";
     }
     formGroup('text', $name, $label, $input_size, '', $input_value, '', '', '', $champ, ($addon != '' ? $addon : ''));
 }
 
 function desactive_option($name, $list_id, $packid) {
     global $l;
+
     $sql_desactive = "delete from devices where name='%s' and ivalue=%s";
     $arg_desactive = array($name, $packid);
     if ($list_id != '') {
@@ -115,17 +117,36 @@ function desactive_option($name, $list_id, $packid) {
 
 function active_option($name, $list_id, $packid, $tvalue = '') {
     global $l;
-    desactive_option($name, $list_id, $packid);
-    $sql_active = "insert into devices (HARDWARE_ID, NAME, IVALUE,TVALUE) select ID,'%s','%s',";
-    if ($tvalue == '') {
-        $sql_active .= "null from hardware where id in ";
-        $arg_active = array($name, $packid);
-    } else {
-        $sql_active .= "'%s' from hardware where id in ";
-        $arg_active = array($name, $packid, $tvalue);
-    }
-    $sql = mysql2_prepare($sql_active, $arg_active, $list_id);
-    mysql2_query_secure($sql['SQL'], $_SESSION['OCS']["writeServer"], $sql['ARG'], $l->g(512));
+
+		if(strpos($packid, ',')) {
+			$pack_id = explode(',',$packid);
+			foreach($pack_id as $key => $value){
+				desactive_option($name, $list_id, $value);
+		    $sql_active = "insert into devices (HARDWARE_ID, NAME, IVALUE,TVALUE) select ID,'%s','%s',";
+		    if ($tvalue == '') {
+		        $sql_active .= "null from hardware where id in ";
+		        $arg_active = array($name, $value);
+		    } else {
+		        $sql_active .= "'%s' from hardware where id in ";
+		        $arg_active = array($name, $value, $tvalue);
+		    }
+		    $sql = mysql2_prepare($sql_active, $arg_active, $list_id);
+		    mysql2_query_secure($sql['SQL'], $_SESSION['OCS']["writeServer"], $sql['ARG'], $l->g(512));
+			}
+		} else {
+				desactive_option($name, $list_id, $packid);
+		    $sql_active = "insert into devices (HARDWARE_ID, NAME, IVALUE,TVALUE) select ID,'%s','%s',";
+		    if ($tvalue == '') {
+		        $sql_active .= "null from hardware where id in ";
+		        $arg_active = array($name, $packid);
+		    } else {
+		        $sql_active .= "'%s' from hardware where id in ";
+		        $arg_active = array($name, $packid, $tvalue);
+		    }
+		    $sql = mysql2_prepare($sql_active, $arg_active, $list_id);
+		    mysql2_query_secure($sql['SQL'], $_SESSION['OCS']["writeServer"], $sql['ARG'], $l->g(512));
+		}
+
     return( mysqli_affected_rows($_SESSION['OCS']["writeServer"]) );
 }
 
@@ -222,6 +243,8 @@ function activ_pack($fileid, $https_server, $file_serv) {
 		$reqEnable = "SELECT * FROM download_enable WHERE fileid=%s";
 		$argEnable = array($fileid);
 		$result = mysql2_query_secure($reqEnable, $_SESSION['OCS']["readServer"], $argEnable);
+		$listInfoLoc = array();
+		$listPackLoc = array();
 		while($recVerif = mysqli_fetch_array($result)){
 				$listInfoLoc[] = $recVerif['INFO_LOC'];
 				$listPackLoc[] = $recVerif['PACK_LOC'];
@@ -252,7 +275,7 @@ function activ_pack_server($fileid, $https_server, $id_server_group) {
         if ($valDoub['INFO_LOC'] != $https_server) {
             $sql_update_https = "UPDATE download_enable SET download_enable.INFO_LOC='%s' WHERE SERVER_ID=%s";
             $arg_update_https = array($https_server, $valDoub['SERVER_ID']);
-            mysql2_query_secure($sql_update_https, $_SESSION['OCS']["readServer"], $arg_update_https);
+            mysql2_query_secure($sql_update_https, $_SESSION['OCS']["writeServer"], $arg_update_https);
         }
     }
     //If this list is not null, we create the end of sql request
@@ -370,7 +393,7 @@ function recursive_remove_directory($directory, $empty = false) {
     return true;
 }
 
-function create_pack($sql_details, $info_details) {
+function create_pack($sql_details, $info_details, $modif = "true") {
     global $l;
 
     if (DEMO) {
@@ -378,82 +401,136 @@ function create_pack($sql_details, $info_details) {
         return;
     }
 
-    $info_details = xml_escape_string($info_details);
-    //get temp file
-    $fname = $sql_details['document_root'] . $sql_details['timestamp'] . "/tmp";
-    //cut this package
-    if ($size = @filesize($fname)) {
-        $handle = fopen($fname, "rb");
-        $read = 0;
-        for ($i = 1; $i < $sql_details['nbfrags']; $i++) {
-            $contents = fread($handle, $size / $sql_details['nbfrags']);
+    // Convert packages details in a properly UTF-8 encoded HTML string.
+    foreach ($info_details as $key => $value) {
+        if (mb_detect_encoding($value)!== 'UTF-8') {
+          $info_details[$key] = mb_convert_encoding($value, 'UTF-8');
+        }
+        $info_details[$key] = htmlspecialchars($value, ENT_QUOTES);
+    }
+
+    if($modif == "true"){
+	    //get temp file
+        $fname = $sql_details['document_root'] . $sql_details['timestamp'] . "/tmp";
+        //cut this package
+        if ($size = @filesize($fname)) {
+            $handle = fopen($fname, "rb");
+            $read = 0;
+            for ($i = 1; $i < $sql_details['nbfrags']; $i++) {
+                $contents = fread($handle, $size / $sql_details['nbfrags']);
+                $read += strlen($contents);
+                $handfrag = fopen($sql_details['document_root'] . $sql_details['timestamp'] . "/" . $sql_details['timestamp'] . "-" . $i, "w+b");
+                fwrite($handfrag, $contents);
+                fclose($handfrag);
+            }
+
+            $contents = fread($handle, $size - $read);
             $read += strlen($contents);
             $handfrag = fopen($sql_details['document_root'] . $sql_details['timestamp'] . "/" . $sql_details['timestamp'] . "-" . $i, "w+b");
             fwrite($handfrag, $contents);
             fclose($handfrag);
+            fclose($handle);
+
+            unlink($sql_details['document_root'] . $sql_details['timestamp'] . "/tmp");
+        } else {
+            if (!file_exists($sql_details['document_root'] . $sql_details['timestamp'])) {
+                mkdir($sql_details['document_root'] . $sql_details['timestamp']);
+            }
         }
 
-        $contents = fread($handle, $size - $read);
-        $read += strlen($contents);
-        $handfrag = fopen($sql_details['document_root'] . $sql_details['timestamp'] . "/" . $sql_details['timestamp'] . "-" . $i, "w+b");
-        fwrite($handfrag, $contents);
-        fclose($handfrag);
-        fclose($handle);
+        if (!is_defined($info_details['DIGEST'])) {
+            $sql_details['nbfrags'] = 0;
+        }
 
-        unlink($sql_details['document_root'] . $sql_details['timestamp'] . "/tmp");
+        //create info
+        if($sql_details['nbfrags'] == null) {
+            $sql_details['nbfrags'] = '0';
+        }
+
+        $info = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+        $info .= "<DOWNLOAD ID=\"" . $sql_details['timestamp'] . "\" " .
+                "PRI=\"" . $info_details['PRI'] . "\" " .
+                "ACT=\"" . $info_details['ACT'] . "\" " .
+                "DIGEST=\"" . $info_details['DIGEST'] . "\" " .
+                "PROTO=\"" . $info_details['PROTO'] . "\" " .
+                "FRAGS=\"" . $sql_details['nbfrags'] . "\" " .
+                "DIGEST_ALGO=\"" . $info_details['DIGEST_ALGO'] . "\" " .
+                "DIGEST_ENCODE=\"" . $info_details['DIGEST_ENCODE'] . "\" ";
+        if ($info_details['ACT'] == 'STORE') {
+            $info .= "PATH=\"" . $info_details['PATH'] . "\" ";
+        }
+        if ($info_details['ACT'] == 'LAUNCH') {
+            $info .= "NAME=\"" . $info_details['NAME'] . "\" ";
+        }
+        if ($info_details['ACT'] == 'EXECUTE') {
+            $info .= "COMMAND=\"" . $info_details['COMMAND'] . "\" ";
+        }
+
+        $notifyText = htmlspecialchars($info_details['NOTIFY_TEXT'], ENT_QUOTES);
+        $actionText = addslashes($info_details['NEED_DONE_ACTION_TEXT']);
+
+        $info .= "NOTIFY_USER=\"" . $info_details['NOTIFY_USER'] . "\" " .
+                "NOTIFY_TEXT=\"" . $notifyText . "\" " .
+                "NOTIFY_COUNTDOWN=\"" . $info_details['NOTIFY_COUNTDOWN'] . "\" " .
+                "NOTIFY_CAN_ABORT=\"" . $info_details['NOTIFY_CAN_ABORT'] . "\" " .
+                "NOTIFY_CAN_DELAY=\"" . $info_details['NOTIFY_CAN_DELAY'] . "\" " .
+                "NEED_DONE_ACTION=\"" . $info_details['NEED_DONE_ACTION'] . "\" " .
+                "NEED_DONE_ACTION_TEXT=\"" . $actionText . "\" " .
+                "GARDEFOU=\"" . $info_details['GARDEFOU'] . "\" />\n";
+
+        $handinfo = fopen($sql_details['document_root'] . $sql_details['timestamp'] . "/info", "w+");
+        fwrite($handinfo, $info);
+        fclose($handinfo);
+
+        //delete all package with the same id
+        mysql2_query_secure("DELETE FROM download_available WHERE FILEID='%s'", $_SESSION['OCS']["writeServer"], $sql_details['timestamp']);
+        //insert new package
+        $req = "INSERT INTO download_available(FILEID, NAME, PRIORITY, FRAGMENTS, SIZE, OSNAME, COMMENT,ID_WK) VALUES
+            ( '%s', '%s','%s', '%s','%s', '%s', '%s','%s' )";
+        $arg = array($sql_details['timestamp'], $sql_details['name'], $info_details['PRI'], $sql_details['nbfrags'],
+            $sql_details['size'], $sql_details['os'], $sql_details['description'], $sql_details['id_wk']);
+        mysql2_query_secure($req, $_SESSION['OCS']["writeServer"], $arg);
     } else {
-        if (!file_exists($sql_details['document_root'] . $sql_details['timestamp'])) {
-            mkdir($sql_details['document_root'] . $sql_details['timestamp']);
+        $file = $sql_details['document_root'] . $sql_details['timestamp'] . "/info";
+
+        $dom = new DOMDocument();
+        $dom->load($file);
+
+        $xpath = new DOMXPath($dom);
+        $elements = $xpath->query("//*[starts-with(local-name(), 'DOWNLOAD')]");
+
+        $notifyText = $info_details['NOTIFY_TEXT'];
+        $actionText = addslashes($info_details['NEED_DONE_ACTION_TEXT']);
+
+        if ($elements->length >= 1) {
+            $element = $elements->item(0);
+            $element->setAttribute('PRI', $info_details['PRI']);
+            $element->setAttribute('ACT', $info_details['ACT']);
+            $element->setAttribute('PROTO', $info_details['PROTO']);
+            if ($info_details['ACT'] == 'STORE') {
+                $element->setAttribute('PATH', $info_details['PATH']);
+            }
+            if ($info_details['ACT'] == 'EXECUTE') {
+                $element->setAttribute('COMMAND', $info_details['COMMAND']);
+            }
+            $element->setAttribute('NOTIFY_USER', $info_details['NOTIFY_USER']);
+            $element->setAttribute('NOTIFY_TEXT', $notifyText);
+            $element->setAttribute('NOTIFY_COUNTDOWN', $info_details['NOTIFY_COUNTDOWN']);
+            $element->setAttribute('NOTIFY_CAN_ABORT', $info_details['NOTIFY_CAN_ABORT']);
+            $element->setAttribute('NOTIFY_CAN_DELAY', $info_details['NOTIFY_CAN_DELAY']);
+            $element->setAttribute('NEED_DONE_ACTION', $info_details['NEED_DONE_ACTION']);
+            $element->setAttribute('NEED_DONE_ACTION_TEXT', $actionText);
+            $element->setAttribute('GARDEFOU', $info_details['GARDEFOU']);
         }
-    }
-    if (!is_defined($info_details['DIGEST'])) {
-        $sql_details['nbfrags'] = 0;
-    }
 
-    //create info
-    $info = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
-    $info .= "<DOWNLOAD ID=\"" . $sql_details['timestamp'] . "\" " .
-            "PRI=\"" . $info_details['PRI'] . "\" " .
-            "ACT=\"" . $info_details['ACT'] . "\" " .
-            "DIGEST=\"" . $info_details['DIGEST'] . "\" " .
-            "PROTO=\"" . $info_details['PROTO'] . "\" " .
-            "FRAGS=\"" . $sql_details['nbfrags'] . "\" " .
-            "DIGEST_ALGO=\"" . $info_details['DIGEST_ALGO'] . "\" " .
-            "DIGEST_ENCODE=\"" . $info_details['DIGEST_ENCODE'] . "\" ";
-    if ($info_details['ACT'] == 'STORE') {
-        $info .= "PATH=\"" . $info_details['PATH'] . "\" ";
+        $dom->save($file);
+
+        // Update package
+        $req = "UPDATE download_available SET NAME = '%s', PRIORITY = '%s', OSNAME = '%s', COMMENT = '%s' WHERE FILEID = '%s'";
+        $arg = array($sql_details['name'], $info_details['PRI'], $sql_details['os'], $sql_details['description'], $sql_details['timestamp']);
+        mysql2_query_secure($req, $_SESSION['OCS']["writeServer"], $arg);
     }
-    if ($info_details['ACT'] == 'LAUNCH') {
-        $info .= "NAME=\"" . $info_details['NAME'] . "\" ";
-    }
-    if ($info_details['ACT'] == 'EXECUTE') {
-        $info .= "COMMAND=\"" . $info_details['COMMAND'] . "\" ";
-    }
-
-    $notifyText = addslashes($info_details['NOTIFY_TEXT']);
-    $actionText = addslashes($info_details['NEED_DONE_ACTION_TEXT']);
-
-    $info .= "NOTIFY_USER=\"" . $info_details['NOTIFY_USER'] . "\" " .
-            "NOTIFY_TEXT=\"" . $notifyText . "\" " .
-            "NOTIFY_COUNTDOWN=\"" . $info_details['NOTIFY_COUNTDOWN'] . "\" " .
-            "NOTIFY_CAN_ABORT=\"" . $info_details['NOTIFY_CAN_ABORT'] . "\" " .
-            "NOTIFY_CAN_DELAY=\"" . $info_details['NOTIFY_CAN_DELAY'] . "\" " .
-            "NEED_DONE_ACTION=\"" . $info_details['NEED_DONE_ACTION'] . "\" " .
-            "NEED_DONE_ACTION_TEXT=\"" . $actionText . "\" " .
-            "GARDEFOU=\"" . $info_details['GARDEFOU'] . "\" />\n";
-
-    $handinfo = fopen($sql_details['document_root'] . $sql_details['timestamp'] . "/info", "w+");
-    fwrite($handinfo, utf8_decode($info));
-    fclose($handinfo);
-
-    //delete all package with the same id
-    mysql2_query_secure("DELETE FROM download_available WHERE FILEID='%s'", $_SESSION['OCS']["writeServer"], $sql_details['timestamp']);
-    //insert new package
-    $req = "INSERT INTO download_available(FILEID, NAME, PRIORITY, FRAGMENTS, SIZE, OSNAME, COMMENT,ID_WK) VALUES
-		( '%s', '%s','%s', '%s','%s', '%s', '%s','%s' )";
-    $arg = array($sql_details['timestamp'], $sql_details['name'], $info_details['PRI'], $sql_details['nbfrags'],
-        $sql_details['size'], $sql_details['os'], $sql_details['description'], $sql_details['id_wk']);
-    mysql2_query_secure($req, $_SESSION['OCS']["writeServer"], $arg);
+  
     addLog($l->g(512), $l->g(617) . " " . $sql_details['timestamp']);
     //info message
     msg_success($l->g(437) . " " . $sql_details['document_root'] . $sql_details['timestamp']);
@@ -476,15 +553,22 @@ function crypt_file($dir_FILES, $digest_algo, $digest_encod) {
     return $digest;
 }
 
-function creat_temp_file($directory, $dir_FILES) {
+function creat_temp_file($directory, $dir_FILES, $modif = false) {
     if (DEMO) {
         return;
     }
 
     if (!file_exists($directory . "/tmp")) {
-        if (!@mkdir($directory) || !copy($dir_FILES, $directory . "/tmp")) {
+			if($modif == false){
+				if (!@mkdir($directory) || !copy($dir_FILES, $directory . "/tmp")) {
             msg_error("ERROR: can't create or write in " . $directory . " folder, please refresh when fixed.<br>(or try disabling php safe mode)");
         }
+			}else{
+				if (!copy($dir_FILES, $directory . "/tmp")) {
+            msg_error("ERROR: can't create or write in " . $directory . " folder, please refresh when fixed.<br>(or try disabling php safe mode)");
+        }
+			}
+
     }
 }
 
